@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,8 +52,6 @@ package com.openexchange.messaging.twitter.session;
 import java.util.Iterator;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
-import com.openexchange.messaging.twitter.services.TwitterMessagingServiceRegistry;
-import com.openexchange.sessiond.SessiondService;
 import com.openexchange.twitter.TwitterAccess;
 
 /**
@@ -142,11 +140,7 @@ public final class TwitterAccessRegistry {
      * @return <code>true</code> if a twitter access for given user-context-pair was found and removed; otherwise <code>false</code>
      */
     public boolean removeAccessIfLast(final int contextId, final int userId) {
-        final SessiondService sessiondService = TwitterMessagingServiceRegistry.getServiceRegistry().getService(SessiondService.class);
-        if (null == sessiondService || null == sessiondService.getAnyActiveSessionForUser(userId, contextId)) {
-            return (null != map.remove(SimpleKey.valueOf(contextId, userId)));
-        }
-        return false;
+        return (null != map.remove(SimpleKey.valueOf(contextId, userId)));
     }
 
     /**
