@@ -56,6 +56,7 @@ import java.net.URL;
 import java.net.URLDecoder;
 import java.util.ArrayList;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.Date;
 import java.util.LinkedList;
 import java.util.List;
@@ -80,7 +81,7 @@ import com.openexchange.rss.osgi.Services;
 import com.openexchange.rss.preprocessors.RssPreprocessor;
 import com.openexchange.rss.preprocessors.SanitizingPreprocessor;
 import com.openexchange.rss.util.RssProperties;
-import com.openexchange.rss.util.TimoutHttpURLFeedFetcher;
+import com.openexchange.rss.util.TimeoutHttpURLFeedFetcher;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.session.ServerSession;
 import com.sun.syndication.feed.synd.SyndContent;
@@ -102,15 +103,17 @@ public class RssAction implements AJAXActionService {
     private static final int NOT_FOUND = 404;
     private static final int FORBIDDEN = 403;
 
-    private final TimoutHttpURLFeedFetcher fetcher;
-    private final HashMapFeedInfoCache feedCache;
+    // ------------------------------------------------------------------------------------------------------------------------------
+
+    private final TimeoutHttpURLFeedFetcher fetcher;
+    private final HashMapFeedInfoCache     feedCache;
 
     /**
      * Initializes a new {@link RssAction}.
      */
     public RssAction() {
         feedCache = new HashMapFeedInfoCache();
-        fetcher = new TimoutHttpURLFeedFetcher(10000, 30000, feedCache);
+        fetcher = new TimeoutHttpURLFeedFetcher(10000, 30000, feedCache);
     }
 
     @Override
@@ -138,6 +141,7 @@ public class RssAction implements AJAXActionService {
         List<RssResult> results = new ArrayList<RssResult>(feeds.size());
         boolean dropExternalImages = AJAXRequestDataTools.parseBoolParameter("drop_images", request, true);
         RssPreprocessor preprocessor = new SanitizingPreprocessor(dropExternalImages);
+        Date now = new Date();
 
         for (SyndFeed feed : feeds) {
             if (feed == null) {
@@ -145,18 +149,28 @@ public class RssAction implements AJAXActionService {
             }
 
             // Iterate feed's entries
+            String feedTitle = feed.getTitle();
+            String imageUrl = null;
+            String feedUrl;
+            try {
+                feedUrl = checkUrl(feed.getLink());
+                SyndImage image = feed.getImage();
+                if (image != null) {
+                    imageUrl = checkUrl(image.getUrl());
+                }
+            } catch (MalformedURLException e) {
+                throw RssExceptionCodes.INVALID_RSS.create(e, feed.getLink());
+            }
             for (Object obj : feed.getEntries()) {
                 SyndEntry entry = (SyndEntry) obj;
                 // Create appropriate RssResult instance
                 RssResult result;
                 try {
-                    result = new RssResult().setAuthor(entry.getAuthor()).setSubject(sanitiseString(entry.getTitle())).setUrl(checkUrl(entry.getLink()));
-                    result.setFeedUrl(checkUrl(feed.getLink())).setFeedTitle(sanitiseString(feed.getTitle())).setDate(entry.getUpdatedDate(), entry.getPublishedDate(), new Date());
-
+                    result = new RssResult().setAuthor(entry.getAuthor()).setSubject(entry.getTitle()).setUrl(checkUrl(entry.getLink()));
+                    result.setFeedUrl(feedUrl).setFeedTitle(feedTitle).setDate(entry.getUpdatedDate(), entry.getPublishedDate(), now);
                     // Check possible image
-                    SyndImage image = feed.getImage();
-                    if (image != null) {
-                        result.setImageUrl(checkUrl(image.getUrl()));
+                    if (imageUrl != null) {
+                        result.setImageUrl(imageUrl);
                     }
                 } catch (MalformedURLException e) {
                     throw RssExceptionCodes.INVALID_RSS.create(e, entry.getLink());
@@ -165,16 +179,25 @@ public class RssAction implements AJAXActionService {
                 results.add(result);
 
                 @SuppressWarnings("unchecked") List<SyndContent> contents = entry.getContents();
-                boolean foundHtml = false;
-                for (SyndContent content : contents) {
-                    if ("html".equals(content.getType())) {
-                        foundHtml = true;
-                        String htmlContent = preprocessor.process(content.getValue(), result);
-                        result.setBody(htmlContent).setFormat("text/html");
-                        break;
+                if (contents.isEmpty()) {
+                    /* Change for bug 52689: If no content is available at least display description */
+                    SyndContent description = entry.getDescription();
+                    if (null != description) {
+                        result.setBody(sanitiseString(description.getValue())).setFormat("text/html");
                     }
-                    if (!foundHtml) {
-                        result.setBody(content.getValue()).setFormat(content.getType());
+                } else {
+                    boolean foundHtml = false;
+                    for (SyndContent content : contents) {
+                        String type = content.getType();
+                        if (null != type && (type.startsWith("htm") || type.startsWith("xhtm"))) {
+                            foundHtml = true;
+                            String htmlContent = preprocessor.process(content.getValue(), result);
+                            result.setBody(htmlContent).setFormat("text/html");
+                            break;
+                        }
+                        if (!foundHtml) {
+                            result.setBody(content.getValue()).setFormat(type);
+                        }
                     }
                 }
             }
@@ -197,7 +220,7 @@ public class RssAction implements AJAXActionService {
 
     /**
      * Retrieves all RSS URLs wrapped in the given request.
-     * 
+     *
      * @param request - the {@link AJAXRequestData} containing all feed URLs
      * @return {@link List} with desired feed URLs for further processing
      * @throws OXException
@@ -227,7 +250,7 @@ public class RssAction implements AJAXActionService {
 
     /**
      * Checks given URLs for validity (esp. host name blacklisting and port whitelisting) and adds not accepted feeds to the provided warnings list. Returns a list of accepted feeds for further processing
-     * 
+     *
      * @param urls - List of {@link URL}s to check
      * @param warnings - List of {@link OXException} that might be enhanced by possible errors
      * @return {@link List} of {@link SyndFeed}s that have been accepted for further processing
@@ -237,7 +260,7 @@ public class RssAction implements AJAXActionService {
         List<SyndFeed> feeds = new LinkedList<SyndFeed>();
 
         for (URL url : urls) {
-            if (RssProperties.isDenied(url.getProtocol(), url.getHost(), url.getPort())) {
+            if (RssProperties.isDenied(url.toString())) {
                 final OXException oxe = RssExceptionCodes.RSS_CONNECTION_ERROR.create(url.toString());
                 warnings.add(oxe);
                 continue;
@@ -313,12 +336,19 @@ public class RssAction implements AJAXActionService {
     }
 
     /**
+<<<<<<< HEAD
      * Sanitises the specified string via the {@link HtmlService}
-     * 
+     *
      * @param string The string to sanitise
      * @return The sanitised string if the {@link HtmlService} is available
+=======
+     * Sanitizes the specified string via the {@link HtmlService}
+     *
+     * @param string The string to sanitize
+     * @return The sanitized string as HTML content if the {@link HtmlService} is available
+>>>>>>> 88a3504f07c... Fix for bug 56420: Return RSS Feed's subject as-is
      */
-    private static String sanitiseString(String string) {
+    private static String sanitiseString(String string) throws OXException {
         final HtmlService htmlService = Services.getService(HtmlService.class);
         if (htmlService == null) {
             LOG.warn("The HTMLService is unavailable at the moment, thus the RSS string '{}' might not be sanitised", string);
